[Libreoffice-commits] core.git: 3 commits - filter/source hwpfilter/source include/sal lotuswordpro/source odk/examples offapi/com reportbuilder/java sd/source svx/source sw/inc sw/source vcl/source

Julien Nabet serval2412 at yahoo.fr
Thu Feb 6 13:42:18 PST 2014


 filter/source/flash/swfwriter1.cxx                           |    2 +-
 filter/source/graphicfilter/eps/eps.cxx                      |    2 +-
 hwpfilter/source/hpara.h                                     |    2 +-
 include/sal/types.h                                          |    4 ++--
 lotuswordpro/source/filter/LotusWordProImportFilter.cxx      |    2 +-
 lotuswordpro/source/filter/lwpframelayout.cxx                |    2 +-
 odk/examples/java/Text/HardFormatting.java                   |    4 ++--
 offapi/com/sun/star/drawing/DocumentSettings.idl             |    2 +-
 reportbuilder/java/org/libreoffice/report/pentaho/smil.css   |    2 +-
 reportbuilder/java/org/libreoffice/report/pentaho/svg.css    |    2 +-
 reportbuilder/java/org/libreoffice/report/pentaho/xsl-fo.css |    2 +-
 sd/source/core/sdpage.cxx                                    |    2 +-
 svx/source/gengal/gengal.cxx                                 |    2 +-
 sw/inc/doc.hxx                                               |    2 +-
 sw/inc/expfld.hxx                                            |    6 +++---
 sw/inc/fesh.hxx                                              |    2 +-
 sw/inc/fldbas.hxx                                            |    2 +-
 sw/inc/paratr.hxx                                            |    2 +-
 sw/inc/swtypes.hxx                                           |    4 ++--
 sw/source/core/inc/frame.hxx                                 |    2 +-
 sw/source/core/layout/dbg_lay.cxx                            |    6 +++---
 sw/source/core/layout/layact.cxx                             |    2 +-
 sw/source/core/text/widorp.cxx                               |    2 +-
 sw/source/filter/ww8/ww8par.hxx                              |    2 +-
 sw/source/filter/ww8/ww8par4.cxx                             |    2 +-
 sw/source/ui/fldui/fldvar.cxx                                |    2 +-
 sw/source/ui/uiview/formatclipboard.cxx                      |    2 +-
 sw/source/ui/uno/unotxdoc.cxx                                |    2 +-
 vcl/source/app/settings.cxx                                  |    2 +-
 vcl/source/window/status.cxx                                 |    2 +-
 30 files changed, 37 insertions(+), 37 deletions(-)

New commits:
commit 9bbb7ca9f730217f872462086493ba281ad399f8
Author: Julien Nabet <serval2412 at yahoo.fr>
Date:   Thu Feb 6 22:41:09 2014 +0100

    Typo: formating -> formatting
    
    Change-Id: If4aba89909a3ef049a756182c37d8a5d6812ae70

diff --git a/filter/source/flash/swfwriter1.cxx b/filter/source/flash/swfwriter1.cxx
index c787275..d5c07a6 100644
--- a/filter/source/flash/swfwriter1.cxx
+++ b/filter/source/flash/swfwriter1.cxx
@@ -1298,7 +1298,7 @@ bool Writer::Impl_writeFilling( SvtGraphicFill& rFilling )
 
 /* CL: The idea was to export page fields as text fields that get theire
    string from a variable set with actionscript by each page. This didn't
-   work out since the formating is always wrong when text follows the
+   work out since the formatting is always wrong when text follows the
    page number field since pages greater one may require more space than
    page 1
 */
diff --git a/filter/source/graphicfilter/eps/eps.cxx b/filter/source/graphicfilter/eps/eps.cxx
index 0528316..e818bd0 100644
--- a/filter/source/graphicfilter/eps/eps.cxx
+++ b/filter/source/graphicfilter/eps/eps.cxx
@@ -50,7 +50,7 @@ using namespace ::com::sun::star::uno;
 
 #define PS_LINESIZE         70      // maximum number of characters a line in the output
 
-#define PS_NONE             0       // formating mode: action which is inserted behind the output
+#define PS_NONE             0       // formatting mode: action which is inserted behind the output
 #define PS_SPACE            1
 #define PS_RET              2
 #define PS_WRAP             4
diff --git a/hwpfilter/source/hpara.h b/hwpfilter/source/hpara.h
index 3ace278..c33d51d 100644
--- a/hwpfilter/source/hpara.h
+++ b/hwpfilter/source/hpara.h
@@ -64,7 +64,7 @@ struct LineInfo
     hunit         sx;                             /* internal */
     hunit         psx;                            /* internal */
     hunit         pex;                            /* internal */
-// for formating
+// for formatting
     hunit         height_sp;
     unsigned short    softbreak;                  // column, page, section
 
diff --git a/include/sal/types.h b/include/sal/types.h
index 11d62ae..8668cd5 100644
--- a/include/sal/types.h
+++ b/include/sal/types.h
@@ -30,8 +30,8 @@ extern "C" {
 #endif
 
 #if defined ( __MINGW32__ ) && !defined ( __USE_MINGW_ANSI_STDIO )
-/* Define to use the C99 formating string for coherence reasons.
- * In mingw-w64 some functions are ported to the ms formating string
+/* Define to use the C99 formatting string for coherence reasons.
+ * In mingw-w64 some functions are ported to the ms formatting string
  * some are not yet. This is the only way to make the formatting
  * strings work all the time
  */
diff --git a/lotuswordpro/source/filter/LotusWordProImportFilter.cxx b/lotuswordpro/source/filter/LotusWordProImportFilter.cxx
index 826e1b5..f5b3358 100644
--- a/lotuswordpro/source/filter/LotusWordProImportFilter.cxx
+++ b/lotuswordpro/source/filter/LotusWordProImportFilter.cxx
@@ -63,7 +63,7 @@ static const sal_Int8 header[] = { 0x57, 0x6f, 0x72, 0x64, 0x50, 0x72, 0x6f };
 const sal_Int32 MAXCHARS = 65534;
 
  // Simple xml importer, currently the importer is very very simple
- // it only extracts pure text from the wordpro file. Absolutely no formating
+ // it only extracts pure text from the wordpro file. Absolutely no formatting
  // information is currently imported.
  // To reflect the current state of this importer the sax events sent
  // to the document handler are also the simplest possible. In addition to
diff --git a/odk/examples/java/Text/HardFormatting.java b/odk/examples/java/Text/HardFormatting.java
index b94f620..bcd4026 100644
--- a/odk/examples/java/Text/HardFormatting.java
+++ b/odk/examples/java/Text/HardFormatting.java
@@ -80,7 +80,7 @@ public class HardFormatting {
             com.sun.star.text.XTextRange xTextRange = null;
             com.sun.star.beans.XPropertySet xPropertySet = null;
 
-            // BEGIN: 'Hard formating'
+            // BEGIN: 'Hard formatting'
             // the text range not the cursor contains the 'parastyle' property
             xTextRange = xText.getEnd();
             xPropertySet = UnoRuntime.queryInterface(
@@ -152,7 +152,7 @@ public class HardFormatting {
             xPropertyStateValue = xPropertyState.getPropertyState("CharWeight");
             checkPropertyState(xWordCursor, xPropertyStateValue);
 
-            // END: 'Hard formating' Section from the Cookbook
+            // END: 'Hard formatting' Section from the Cookbook
         }
         catch( Exception e) {
             e.printStackTrace(System.err);
diff --git a/offapi/com/sun/star/drawing/DocumentSettings.idl b/offapi/com/sun/star/drawing/DocumentSettings.idl
index 12af86f..7bdd289 100644
--- a/offapi/com/sun/star/drawing/DocumentSettings.idl
+++ b/offapi/com/sun/star/drawing/DocumentSettings.idl
@@ -43,7 +43,7 @@ published service DocumentSettings
 
 
     /** This is the default logical measure unit that is used for string
-        formating inside the document, f.e. the measure text
+        formatting inside the document, f.e. the measure text
      */
     [optional, property] short MeasureUnit;
 
diff --git a/reportbuilder/java/org/libreoffice/report/pentaho/smil.css b/reportbuilder/java/org/libreoffice/report/pentaho/smil.css
index 54d59ac..debe5cd 100644
--- a/reportbuilder/java/org/libreoffice/report/pentaho/smil.css
+++ b/reportbuilder/java/org/libreoffice/report/pentaho/smil.css
@@ -1,5 +1,5 @@
 @namespace url("urn:oasis:names:tc:opendocument:xmlns:smil-compatible:1.0");
 
 /**
- * All default styles for formating-objects elements (if there are any).
+ * All default styles for formatting-objects elements (if there are any).
 */
diff --git a/reportbuilder/java/org/libreoffice/report/pentaho/svg.css b/reportbuilder/java/org/libreoffice/report/pentaho/svg.css
index ebe16e3..e4bdcf0 100644
--- a/reportbuilder/java/org/libreoffice/report/pentaho/svg.css
+++ b/reportbuilder/java/org/libreoffice/report/pentaho/svg.css
@@ -1,5 +1,5 @@
 @namespace url("urn:oasis:names:tc:opendocument:xmlns:svg-compatible:1.0");
 
 /**
- * All default styles for formating-objects elements (if there are any).
+ * All default styles for formatting-objects elements (if there are any).
 */
diff --git a/reportbuilder/java/org/libreoffice/report/pentaho/xsl-fo.css b/reportbuilder/java/org/libreoffice/report/pentaho/xsl-fo.css
index f030a38..9cb08ac 100644
--- a/reportbuilder/java/org/libreoffice/report/pentaho/xsl-fo.css
+++ b/reportbuilder/java/org/libreoffice/report/pentaho/xsl-fo.css
@@ -1,5 +1,5 @@
 @namespace url("urn:oasis:names:tc:opendocument:xmlns:xsl-fo-compatible:1.0");
 
 /**
- * All default styles for formating-objects elements (if there are any).
+ * All default styles for formatting-objects elements (if there are any).
 */
diff --git a/sd/source/core/sdpage.cxx b/sd/source/core/sdpage.cxx
index 3bd13e4..1e17fad 100644
--- a/sd/source/core/sdpage.cxx
+++ b/sd/source/core/sdpage.cxx
@@ -2534,7 +2534,7 @@ const OUString& SdPage::GetName() const
             aCreatedPageName += " ";
             if( GetModel()->GetPageNumType() == SVX_NUMBER_NONE )
             {
-                // if the document has number none as a formating
+                // if the document has number none as a formatting
                 // for page numbers we still default to arabic numbering
                 // to keep the default page names unique
                 aCreatedPageName += OUString::number( (sal_Int32)nNum );
diff --git a/svx/source/gengal/gengal.cxx b/svx/source/gengal/gengal.cxx
index 2305d3b..1df2f62 100644
--- a/svx/source/gengal/gengal.cxx
+++ b/svx/source/gengal/gengal.cxx
@@ -10,7 +10,7 @@
 
 // Include this before stdio.h for the __MINGW32__ sake.
 // This header contails a define that modifies the way
-// formating strings work for the mingw platforms.
+// formatting strings work for the mingw platforms.
 #include <sal/types.h>
 
 #include <stdio.h>
diff --git a/sw/inc/doc.hxx b/sw/inc/doc.hxx
index b4915e5..2450a81 100644
--- a/sw/inc/doc.hxx
+++ b/sw/inc/doc.hxx
@@ -1292,7 +1292,7 @@ public:
     SwGrfFmtColl* FindGrfFmtCollByName( const OUString& rName ) const
         {   return (SwGrfFmtColl*)FindFmtByName( (SwFmtsBase&)*mpGrfFmtCollTbl, rName ); }
 
-    /// Table formating
+    /// Table formatting
     const SwFrmFmts* GetTblFrmFmts() const  { return mpTblFrmFmtTbl; }
           SwFrmFmts* GetTblFrmFmts()        { return mpTblFrmFmtTbl; }
     sal_uInt16 GetTblFrmFmtCount( bool bUsed ) const;
diff --git a/sw/inc/fesh.hxx b/sw/inc/fesh.hxx
index 57b58ba..6ca2008 100644
--- a/sw/inc/fesh.hxx
+++ b/sw/inc/fesh.hxx
@@ -384,7 +384,7 @@ public:
           SwFrmFmt* GetFlyFrmFmt();
 
     /** OLE. Server requires new size. Desired values are adjusted as frame attributes.
-     If the values are not allowed, the formating clips and determines scaling.
+     If the values are not allowed, the formatting clips and determines scaling.
      See CalcAndSetScale().
      The @return value is the applied size. */
     Size RequestObjectResize( const SwRect &rRect, const ::com::sun::star::uno::Reference < ::com::sun::star::embed::XEmbeddedObject >& );
diff --git a/sw/inc/fldbas.hxx b/sw/inc/fldbas.hxx
index 29dae27..f1c6ac9 100644
--- a/sw/inc/fldbas.hxx
+++ b/sw/inc/fldbas.hxx
@@ -200,7 +200,7 @@ namespace nsSwExtendedSubType
 {
     const SwExtendedSubType SUB_CMD         = 0x0100;   ///< Show command.
     const SwExtendedSubType SUB_INVISIBLE   = 0x0200;   ///< Invisible.
-    const SwExtendedSubType SUB_OWN_FMT     = 0x0400;   ///< SwDBField: Don't accept formating from database.
+    const SwExtendedSubType SUB_OWN_FMT     = 0x0400;   ///< SwDBField: Don't accept formatting from database.
 }
 
 enum SwInputFieldSubType
diff --git a/sw/inc/paratr.hxx b/sw/inc/paratr.hxx
index 6bafd28..01b06c1 100644
--- a/sw/inc/paratr.hxx
+++ b/sw/inc/paratr.hxx
@@ -34,7 +34,7 @@ class IntlWrapper;
 #define DROP_WHOLEWORD ((sal_uInt16)0x0001)
 
 /** If SwFmtDrop is a Client, it is the CharFmt that describes the font for the
-   DropCaps. If it is not a Client, formating uses the CharFmt of the paragraph.
+   DropCaps. If it is not a Client, formatting uses the CharFmt of the paragraph.
    If the CharFmt is modified, this change is propagated to the paragraphs
    via the Modify of SwFmtDrop. */
 class SW_DLLPUBLIC SwFmtDrop: public SfxPoolItem, public SwClient
diff --git a/sw/inc/swtypes.hxx b/sw/inc/swtypes.hxx
index 8dec3ff..2c943b1 100644
--- a/sw/inc/swtypes.hxx
+++ b/sw/inc/swtypes.hxx
@@ -258,7 +258,7 @@ enum PrepareHint
     PREP_WIDOWS_ORPHANS,    // Only check for widows and orphans and split in case of need.
     PREP_FIXSIZE_CHG,       // FixSize has changed.
     PREP_FOLLOW_FOLLOWS,    // Follow is now possibly adjacent.
-    PREP_ADJUST_FRM,        // Adjust size via grow/shrink without formating.
+    PREP_ADJUST_FRM,        // Adjust size via grow/shrink without formatting.
     PREP_FLY_CHGD,          // A FlyFrm has changed its size.
     PREP_FLY_ATTR_CHG,      // A FlyFrm hat has changed its attributes
                             // (e. g. wrap).
@@ -289,7 +289,7 @@ enum PrepareHint
     PREP_REGISTER,          // Invalidate frames with registers.
     PREP_FTN_GONE,          // A Follow loses its footnote, possibly its first line can move up.
     PREP_MOVEFTN,           // A footnote changes its page. Its contents receives at first a
-                            // height of zero in order to avoid too much noise. At formating
+                            // height of zero in order to avoid too much noise. At formatting
                             // it checks whether it fits and if necessary changes its page again.
     PREP_ERGOSUM,           // Needed because of movement in FtnFrms. Check QuoVadis/ErgoSum.
     PREP_END                // END.
diff --git a/sw/source/core/inc/frame.hxx b/sw/source/core/inc/frame.hxx
index b53459e..2848948 100644
--- a/sw/source/core/inc/frame.hxx
+++ b/sw/source/core/inc/frame.hxx
@@ -387,7 +387,7 @@ protected:
     void MakePos();
     // Format next frame of table frame to assure keeping attributes.
     // In case of nested tables method <SwFrm::MakeAll()> is called to
-    // avoid formating of superior table frame.
+    // avoid formatting of superior table frame.
     friend SwFrm* sw_FormatNextCntntForKeep( SwTabFrm* pTabFrm );
 
     virtual void MakeAll() = 0;
diff --git a/sw/source/core/layout/dbg_lay.cxx b/sw/source/core/layout/dbg_lay.cxx
index 2d9803a..901b843 100644
--- a/sw/source/core/layout/dbg_lay.cxx
+++ b/sw/source/core/layout/dbg_lay.cxx
@@ -182,7 +182,7 @@ class SwImplProtocol
     sal_uInt16 nLineCount;          // printed lines
     sal_uInt16 nMaxLines;           // max lines to be printed
     sal_uInt8 nInitFile;            // range (FrmId,FrmType,Record) during reading of the INI file
-    sal_uInt8 nTestMode;            // special for test formating, logging may only be done in test formating.
+    sal_uInt8 nTestMode;            // special for test formatting, logging may only be done in test formatting.
     void _Record( const SwFrm* pFrm, sal_uLong nFunction, sal_uLong nAct, void* pParam );
     bool NewStream();
     void CheckLine( OString& rLine );
@@ -374,7 +374,7 @@ void SwImplProtocol::CheckLine( OString& rLine )
         else if (aTmp == "[test")// section functions
         {
             nInitFile = 4; // default:
-            nTestMode = 0; // log outside of test formating
+            nTestMode = 0; // log outside of test formatting
         }
         else if (aTmp == "[max")// Max number of lines
         {
@@ -593,7 +593,7 @@ void SwImplProtocol::_Record( const SwFrm* pFrm, sal_uLong nFunction, sal_uLong
         return; // the type is unwanted
 
     if( 1 == nTestMode && nFunction != PROT_TESTFORMAT )
-        return; // we may only log inside a test formating
+        return; // we may only log inside a test formatting
     sal_Bool bTmp = sal_False;
     OStringBuffer aOut(aLayer);
     aOut.append(static_cast<sal_Int64>(lcl_GetFrameId(pFrm)));
diff --git a/sw/source/core/layout/layact.cxx b/sw/source/core/layout/layact.cxx
index b9222fd..7cd5400 100644
--- a/sw/source/core/layout/layact.cxx
+++ b/sw/source/core/layout/layact.cxx
@@ -1503,7 +1503,7 @@ sal_Bool SwLayAction::FormatLayout( SwLayoutFrm *pLay, sal_Bool bAddRect )
         pLow = pLow->GetNext();
     }
     // OD 11.11.2002 #104414# - add complete frame area as paint area, if frame
-    // area has been already added and after formating its lowers the frame area
+    // area has been already added and after formatting its lowers the frame area
     // is enlarged.
     SwRect aBoundRect(pLay->IsPageFrm() ? static_cast<SwPageFrm*>(pLay)->GetBoundRect() : pLay->Frm() );
 
diff --git a/sw/source/core/text/widorp.cxx b/sw/source/core/text/widorp.cxx
index 1901082..a621318 100644
--- a/sw/source/core/text/widorp.cxx
+++ b/sw/source/core/text/widorp.cxx
@@ -85,7 +85,7 @@ SwTxtFrmBreak::SwTxtFrmBreak( SwTxtFrm *pNewFrm, const SwTwips nRst )
 
 /* BP 18.6.93: Widows.
  * In contrast to the first implementation the Widows are not calculated
- * in advance but detected when formating the split Follow.
+ * in advance but detected when formatting the split Follow.
  * In Master the Widows-calculation is dropped completely
  * (nWidows is manipulated). If the Follow detects that the
  * Widows rule applies it sends a Prepare to its predecessor.
diff --git a/sw/source/filter/ww8/ww8par.hxx b/sw/source/filter/ww8/ww8par.hxx
index c4425cc..57877bc 100644
--- a/sw/source/filter/ww8/ww8par.hxx
+++ b/sw/source/filter/ww8/ww8par.hxx
@@ -1767,7 +1767,7 @@ public:     // eigentlich private, geht aber leider nur public
     void Read_CFRMark(sal_uInt16 , const sal_uInt8* pData, short nLen);
     // delete old content
     void Read_CFRMarkDel(sal_uInt16 , const sal_uInt8* pData, short nLen);
-    // change properties of content (e.g. char formating)
+    // change properties of content (e.g. char formatting)
     void Read_CPropRMark(sal_uInt16 , const sal_uInt8* pData, short nLen); // complex!
 
 
diff --git a/sw/source/filter/ww8/ww8par4.cxx b/sw/source/filter/ww8/ww8par4.cxx
index 2573a8f..0c8a59c 100644
--- a/sw/source/filter/ww8/ww8par4.cxx
+++ b/sw/source/filter/ww8/ww8par4.cxx
@@ -535,7 +535,7 @@ void SwWW8ImplReader::Read_CFRMarkDel(sal_uInt16 , const sal_uInt8* pData, short
     Read_CRevisionMark( nsRedlineType_t::REDLINE_DELETE, pData, nLen );
 }
 
-// change properties of content ( == char formating)
+// change properties of content ( == char formatting)
 void SwWW8ImplReader::Read_CPropRMark(sal_uInt16 , const sal_uInt8* pData, short nLen)
 {
     // complex (len is always 7)
diff --git a/sw/source/ui/fldui/fldvar.cxx b/sw/source/ui/fldui/fldvar.cxx
index a41cf73..ecd296a 100644
--- a/sw/source/ui/fldui/fldvar.cxx
+++ b/sw/source/ui/fldui/fldvar.cxx
@@ -326,7 +326,7 @@ IMPL_LINK( SwFldVarPage, SubTypeHdl, ListBox *, pBox )
             if (IsFldEdit())
             {
                 // GetFormula leads to problems with date formats because
-                // only the numeric value without formating is returned.
+                // only the numeric value without formatting is returned.
                 // It must be used though because otherwise in GetPar2 only
                 // the value calculated by Kalkulator would be displayed
                 // (instead of test2 = test + 1)
diff --git a/sw/source/ui/uiview/formatclipboard.cxx b/sw/source/ui/uiview/formatclipboard.cxx
index f383d23..2394de4 100644
--- a/sw/source/ui/uiview/formatclipboard.cxx
+++ b/sw/source/ui/uiview/formatclipboard.cxx
@@ -532,7 +532,7 @@ void SwFormatClipboard::Paste( SwWrtShell& rWrtShell, SfxStyleSheetBasePool* pPo
             rWrtShell.SetAttrSet(*pTemplateItemSet);
 
             // store the attributes in aItemVector in order not to apply them as
-            // text automatic formating attributes later in the code
+            // text automatic formatting attributes later in the code
             lcl_AppendSetItems( aItemVector, *pTemplateItemSet);
 
             delete pTemplateItemSet;
diff --git a/sw/source/ui/uno/unotxdoc.cxx b/sw/source/ui/uno/unotxdoc.cxx
index 249cfa6..77c8a0a 100644
--- a/sw/source/ui/uno/unotxdoc.cxx
+++ b/sw/source/ui/uno/unotxdoc.cxx
@@ -2554,7 +2554,7 @@ sal_Int32 SAL_CALL SwXTextDocument::getRendererCount(
                 }
             }
 
-            // reformating the document for printing will show the changes in the view
+            // reformatting the document for printing will show the changes in the view
             // which is likely to produce many unwanted and not nice to view actions.
             // We don't want that! Thus we disable updating of the view.
             pViewShell->StartAction();
diff --git a/vcl/source/window/status.cxx b/vcl/source/window/status.cxx
index cf8794d..3e49da7 100644
--- a/vcl/source/window/status.cxx
+++ b/vcl/source/window/status.cxx
@@ -779,7 +779,7 @@ void StatusBar::Resize()
     mnItemY = STATUSBAR_OFFSET_Y;
     mnTextY = (mnCalcHeight-GetTextHeight())/2;
 
-    // provoke re-formating
+    // provoke re-formatting
     mbFormat = sal_True;
 
     if ( mbProgressMode )
commit 1474d5c9c3274579efc9793614e830725b9384ca
Author: Julien Nabet <serval2412 at yahoo.fr>
Date:   Thu Feb 6 22:37:00 2014 +0100

    -Typo: falback -> fallback
    
    Change-Id: Ic6ad17315d0d4566971f006e3a8736e1608eb934

diff --git a/vcl/source/app/settings.cxx b/vcl/source/app/settings.cxx
index 541f881..3f07a2b 100644
--- a/vcl/source/app/settings.cxx
+++ b/vcl/source/app/settings.cxx
@@ -669,7 +669,7 @@ sal_uLong StyleSettings::GetAutoSymbolsStyle() const
     else
         nRet = STYLE_SYMBOLS_TANGO;
 
-    // falback to any existing style
+    // fallback to any existing style
     if ( ! CheckSymbolStyle (nRet) )
     {
         for ( sal_uLong n = 0 ; n <= STYLE_SYMBOLS_THEMES_MAX  ; n++ )
commit 49801a297a1c107928e0891c9d0c3a01aa7d2d8f
Author: Julien Nabet <serval2412 at yahoo.fr>
Date:   Thu Feb 6 22:36:32 2014 +0100

    Typo: wraped -> wrapped
    
    Change-Id: I657a192a2be21315a3a17dc8a798a084a6f98c34

diff --git a/lotuswordpro/source/filter/lwpframelayout.cxx b/lotuswordpro/source/filter/lwpframelayout.cxx
index 8d9291d..9a73c7b 100644
--- a/lotuswordpro/source/filter/lwpframelayout.cxx
+++ b/lotuswordpro/source/filter/lwpframelayout.cxx
@@ -250,7 +250,7 @@ void LwpFrame::ApplyWrapType(XFFrameStyle *pFrameStyle)
         case LwpPlacableLayout::LAY_WRAP_IRREG_BIGGEST:
         {
             //In SODC, if Optimal wrap type is used and the distance between the frame object
-            //and page margins is less than 2cm, the text is not wraped. While there is no this feature in Word Pro
+            //and page margins is less than 2cm, the text is not wrapped. While there is no this feature in Word Pro
             //So the optimal wrap type is translated to left side or right side wrap type according to the distance
             //between the frame object and page margins
 


More information about the Libreoffice-commits mailing list
diff --git a/sw/inc/expfld.hxx b/sw/inc/expfld.hxx
index 65b9beb..af25a11 100644
--- a/sw/inc/expfld.hxx
+++ b/sw/inc/expfld.hxx
@@ -103,14 +103,14 @@ public:
     inline OUString             GetExpStr() const;
     inline void                 ChgExpStr(const OUString& rExpand);
 
     /// Called by formating.
     inline bool                 IsInBodyTxt() const;
 
     /// Set by UpdateExpFlds where node position is known.
     inline void                 ChgBodyTxtFlag( bool bIsInBody );
 
     /** For fields in header/footer/footnotes/flys:
-     Only called by formating!! */
+     Only called by formatting!! */
     void                        ChangeExpansion( const SwFrm&, const SwTxtFld& );
 
     virtual OUString    GetFieldName() const;
@@ -135,7 +135,7 @@ inline void SwGetExpField::ChgExpStr(const OUString& rExpand)
 inline OUString SwGetExpField::GetExpStr() const
     { return sExpand;   }
 
  /// Called by formating.
 inline bool SwGetExpField::IsInBodyTxt() const
     { return bIsInBodyTxt; }
 
@@ -103,14 +103,14 @@ public:
     inline void                 ChgExpStr(const OUString& rExpand);
 
-    /// Called by formating.
+    /// Called by formatting.
     inline bool                 IsInBodyTxt() const;
 
@@ -135,7 +135,7 @@ inline void SwGetExpField::ChgExpStr(const OUString& rExpand)
     { return sExpand;   }
 
- /// Called by formating.
+ /// Called by formatting.
 inline bool SwGetExpField::IsInBodyTxt() const
     { return bIsInBodyTxt; }